#!/usr/bin/perl
########################################################################
# Copyright (c) 2012 AmdoSoft Systems, all rights reserved.
########################################################################
#
# File:         RemoveOldFiles.pl
# Description:  Remove Old Files
#               It is used to check the files contained in a folder and 
#               remove the ones older than a specified number of days.
#               Usage:
#                 RemoveOldFiles.pl {<folder> <age>} | -v
#               where:
#               <folder> is the complete path of the folder to check.
#               <age> is the file age in days.
#               It returns OCT suitable output in the format:
#               <OCT_status>:<description>
#               -v option returns version information.
#
# Version:      1.1
#
# Revision History
# Version:      1.2
# Description:  It removes files and subfolders
#
########################################################################

use File::Path;

########################################################################
# Main
########################################################################

# OCT Status
$StatUNDETERMINED = "UNDETERMINED";
$StatUP           = "UP";
$StatDOWN         = "DOWN";
$StatOFFLINE      = "OFFLINE";
$StatSTOPPED      = "STOPPED";
$StatUNINSTALLED  = "UNINSTALLED";
$StatINSTALLED    = "INSTALLED";
$StatWARNING      = "WARNING";
$StatDISABLED     = "DISABLED";

########################################################################
# DO NOT MODIFY BELOW THIS LINE
########################################################################

$Version         = "V1.2";
$ApplicationName = "Remove Old Files";

$Folder = "";
$Age    = 0;

########################################################################

sub getParameters
{
    $param0 = $ARGV[0];
    $param1 = $ARGV[1];
}

sub checkParameters
{
    if (($param0 eq "-v") or ($param0 eq "-V") or ($param0 eq "/v") or ($param0 eq "/V"))
    {
        print "$StatINSTALLED:$ApplicationName $Version";
        exit 0;
    }

    $Folder = $param0;
    $Age    = $param1;

    if (($Folder eq "") or ($Age eq ""))
    {
        print "$StatUNDETERMINED:Parameter missing.";
        exit 0;
    }
    if ((not -e $Folder) or (not -d $Folder))
    {
        print "$StatUNDETERMINED:Folder \"$Folder\" does not exist.";
        exit 0;
    }
    if ($Age == 0)
    {
        print "$StatUNDETERMINED:Age is invalid.";
        exit 0;
    }
}

sub performMonitor
{
    my $fileAge = 0;
    my $nDeleted = 0;

    chdir($Folder);
    if (opendir(FOLDER, $Folder))
    {
        while (defined($fileName = readdir(FOLDER)))
        {
            if (-f $fileName)
            {
                $fileAge = -M _;
                if ($fileAge > $Age)
                {
                    # remove
                    unlink($fileName);
                    $nDeleted = $nDeleted+1;
                }
            }
            elsif (-d $fileName)
            {
                if (($fileName ne ".") and ($fileName ne ".."))
                {
                    $fileAge = -M _;
                    if ($fileAge > $Age)
                    {
                        # remove
                        rmtree($fileName);
                        $nDeleted = $nDeleted+1;
                    }
                }
            }
        }

        closedir(FOLDER);
    }

    print "$StatUP:Command completed (removed $nDeleted file(s)/folder(s) older than $Age day(s)).";
}

########################################################################

&getParameters;
&checkParameters;
&performMonitor;

exit 0;
